# Copyright (C) 2008-2009 - INRIA - Michael Baudin
# Copyright (C) 2009-2010 - DIGITEO - Michael Baudin
# Copyright (C) 2010-2014 - Sebastien Bihorel
#
# This file must be used under the terms of the CeCILL.
# This source file is licensed as described in the file COPYING, which
# you should have received as part of this distribution. The terms
# are also available at
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# This source code is a R port of the optimbase component
# originally written by Michael Baudin for Scilab.

optimbase.log <- function(this=NULL,msg=NULL){

  if (this$verbose==TRUE){
    if (this$logfile!=''){
      write(sprintf('%s\n',msg),file=this$logfile,append=TRUE)
    } else {
      cat(msg,'\n')
    }
  }

  return(this)

}

